( cd usr/man/man1 ; rm -rf cc.1.gz )
( cd usr/man/man1 ; ln -sf gcc.1.gz cc.1.gz )
( cd usr/bin ; rm -rf powerpc-slackware-linux-gcc-4.2.3 )
( cd usr/bin ; ln -sf gcc-4.2.3 powerpc-slackware-linux-gcc-4.2.3 )
( cd usr/bin ; rm -rf powerpc-slackware-linux-gcc )
( cd usr/bin ; ln -sf gcc-4.2.3 powerpc-slackware-linux-gcc )
( cd usr/bin ; rm -rf gcc )
( cd usr/bin ; ln -sf gcc-4.2.3 gcc )
( cd usr/bin ; rm -rf cc )
( cd usr/bin ; ln -sf gcc cc )
( cd usr/lib/nof ; rm -rf libgcj.so.8 )
( cd usr/lib/nof ; ln -sf libgcj.so.8.0.0 libgcj.so.8 )
( cd usr/lib/nof ; rm -rf libmudflapth.so.0 )
( cd usr/lib/nof ; ln -sf libmudflapth.so.0.0.0 libmudflapth.so.0 )
( cd usr/lib/nof ; rm -rf libgfortran.so.2 )
( cd usr/lib/nof ; ln -sf libgfortran.so.2.0.0 libgfortran.so.2 )
( cd usr/lib/nof ; rm -rf libgfortran.so )
( cd usr/lib/nof ; ln -sf libgfortran.so.2.0.0 libgfortran.so )
( cd usr/lib/nof ; rm -rf libgcj.so )
( cd usr/lib/nof ; ln -sf libgcj.so.8.0.0 libgcj.so )
( cd usr/lib/nof ; rm -rf libssp.so.0 )
( cd usr/lib/nof ; ln -sf libssp.so.0.0.0 libssp.so.0 )
( cd usr/lib/nof ; rm -rf libgcc_s.so )
( cd usr/lib/nof ; ln -sf libgcc_s.so.1 libgcc_s.so )
( cd usr/lib/nof ; rm -rf libgij.so )
( cd usr/lib/nof ; ln -sf libgij.so.8.0.0 libgij.so )
( cd usr/lib/nof ; rm -rf libobjc.so.2 )
( cd usr/lib/nof ; ln -sf libobjc.so.2.0.0 libobjc.so.2 )
( cd usr/lib/nof ; rm -rf libgcj_bc.so.1 )
( cd usr/lib/nof ; ln -sf libgcj_bc.so.1.0.0 libgcj_bc.so.1 )
( cd usr/lib/nof ; rm -rf libstdc++.so )
( cd usr/lib/nof ; ln -sf libstdc++.so.6.0.9 libstdc++.so )
( cd usr/lib/nof ; rm -rf libobjc.so )
( cd usr/lib/nof ; ln -sf libobjc.so.2.0.0 libobjc.so )
( cd usr/lib/nof ; rm -rf libgcj-tools.so.8 )
( cd usr/lib/nof ; ln -sf libgcj-tools.so.8.0.0 libgcj-tools.so.8 )
( cd usr/lib/nof ; rm -rf libffi.so.4 )
( cd usr/lib/nof ; ln -sf libffi.so.4.0.1 libffi.so.4 )
( cd usr/lib/nof ; rm -rf libgomp.so.1 )
( cd usr/lib/nof ; ln -sf libgomp.so.1.0.0 libgomp.so.1 )
( cd usr/lib/nof ; rm -rf libmudflapth.so )
( cd usr/lib/nof ; ln -sf libmudflapth.so.0.0.0 libmudflapth.so )
( cd usr/lib/nof ; rm -rf libmudflap.so )
( cd usr/lib/nof ; ln -sf libmudflap.so.0.0.0 libmudflap.so )
( cd usr/lib/nof ; rm -rf libgcj-tools.so )
( cd usr/lib/nof ; ln -sf libgcj-tools.so.8.0.0 libgcj-tools.so )
( cd usr/lib/nof ; rm -rf libffi.so )
( cd usr/lib/nof ; ln -sf libffi.so.4.0.1 libffi.so )
( cd usr/lib/nof ; rm -rf libssp.so )
( cd usr/lib/nof ; ln -sf libssp.so.0.0.0 libssp.so )
( cd usr/lib/nof ; rm -rf libgomp.so )
( cd usr/lib/nof ; ln -sf libgomp.so.1.0.0 libgomp.so )
( cd usr/lib/nof ; rm -rf libstdc++.so.6 )
( cd usr/lib/nof ; ln -sf libstdc++.so.6.0.9 libstdc++.so.6 )
( cd usr/lib/nof ; rm -rf libmudflap.so.0 )
( cd usr/lib/nof ; ln -sf libmudflap.so.0.0.0 libmudflap.so.0 )
( cd usr/lib/nof ; rm -rf libgij.so.8 )
( cd usr/lib/nof ; ln -sf libgij.so.8.0.0 libgij.so.8 )
( cd usr/lib ; rm -rf libmudflapth.so.0 )
( cd usr/lib ; ln -sf libmudflapth.so.0.0.0 libmudflapth.so.0 )
( cd usr/lib ; rm -rf libssp.so.0 )
( cd usr/lib ; ln -sf libssp.so.0.0.0 libssp.so.0 )
( cd usr/lib ; rm -rf libgcc_s.so )
( cd usr/lib ; ln -sf libgcc_s.so.1 libgcc_s.so )
( cd usr/lib ; rm -rf libgomp.so.1 )
( cd usr/lib ; ln -sf libgomp.so.1.0.0 libgomp.so.1 )
( cd usr/lib ; rm -rf libmudflapth.so )
( cd usr/lib ; ln -sf libmudflapth.so.0.0.0 libmudflapth.so )
( cd usr/lib ; rm -rf libmudflap.so )
( cd usr/lib ; ln -sf libmudflap.so.0.0.0 libmudflap.so )
( cd usr/lib ; rm -rf libssp.so )
( cd usr/lib ; ln -sf libssp.so.0.0.0 libssp.so )
( cd usr/lib ; rm -rf libgomp.so )
( cd usr/lib ; ln -sf libgomp.so.1.0.0 libgomp.so )
( cd usr/lib ; rm -rf libmudflap.so.0 )
( cd usr/lib ; ln -sf libmudflap.so.0.0.0 libmudflap.so.0 )
( cd lib ; rm -rf cpp )
( cd lib ; ln -sf /usr/bin/cpp cpp )
